<?php

App::uses('EvCheckoutAppModel', 'EvCheckout.Model');
App::uses('CakeEvent', 'Event');

class CustomerAddress extends EvCheckoutAppModel {

	public $hasMany = array(
		'Order' => array(
			'className' => 'EvCheckout.Order'
		)
	);

	public $belongsTo = array(
		'Customer' => array(
			'className' => 'EvCheckout.Customer' 
		)
	);

	public $validate = array(
		'address_line_1' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			)
		),
		'address_line_2' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			)
		),
		'city' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			)
		),
		'postcode' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			)
		)
	);


/**
 * Creates a customer address
 * @param  int  	$userId  	User ID to link address to 
 * @param  array  	$data    	Address information
 * @param  int  	$orderId 	Optional param to link to order. Adds as delivery address by default unless model alias is InvoiceAddress
 * @return mixed 				Returns Address ID if successfully saved else false
 */
	public function createAddress($userId, $data, $orderId = null) {

		$data[$this->alias]['user_id'] = $userId; 

		$this->set($data);

		if($this->save()) {

			//If orderID is set then link to order
			if($orderId !== null) {

				$this->Order->id = $orderId;
				if($this->alias == 'InvoiceAddress') {

					$this->Order->saveField('invoice_address_id', $this->id);
					
				} else {

					$this->Order->saveField('delivery_address_id', $this->id);

				}

			}

			return $this->id; 

		} else {

			return false;

		}

	}

}
